@@ -11,7 +11,7 @@ from preseem import FakeNetworkMetadataModel, NetworkMetadataReference, FakePres
 from preseem.model_sync import sync_preseem_model, ElementSyncItem
 from preseem_protobuf.model.element_pb2 import ElementStatus
 from preseem_protobuf.model.account_pb2 import AccountType, AccountStatus
-from preseem.source_model import Attachment, Router, Service
+from preseem.source_model import Attachment, Olt, Router, Service
 
 Account = namedtuple('Account', ('id', 'type', 'status', 'name', 'first_name', 'last_name'))
 Package = namedtuple('Package', ('id', 'name', 'download_rate', 'upload_rate'))
@@ -21,6 +21,7 @@ class ElementRole:
     AP = UUID('ae3f1aa5-063a-4a24-9744-822a82d107d9')
     ROUTER = UUID('bf433e28-122b-41df-b49a-77ac6544deac')
     CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
+    OLT = UUID('2d9027d6-8639-40eb-8b65-b86c8ee2238b')
 
 def has_any_fields_set(message):
     for field_desc, value in message.ListFields():
@@ -1233,7 +1234,7 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(msvc.updated_at, model_services[0].updated_at)
         self._await(test())
 
-    async def checkSourceRouter(self, sobj):
+    async def checkSourceElement(self, sobj, role_uuid, deleted=False):
         sites = {}
         for site in await self.model.Site.List(company_uuid=self.company.uuid):
             if site.name in sites:
@@ -1243,12 +1244,13 @@ class TestModelSync(unittest.TestCase):
                     sites[site.name] = [sites[site.name], site]
             else:
                 sites[site.name] = site
-        routers = {x.source_id: x for x in await self.model.Element.ListElementDiscovery(company_uuid=self.company.uuid) if x.intent_role_uuid == ElementRole.ROUTER.bytes}
-        mobj = routers.get(sobj.id)
+        mobjs = {x.source_id: x for x in await self.model.Element.ListElementDiscovery(company_uuid=self.company.uuid) if x.intent_role_uuid == role_uuid.bytes}
+        mobj = mobjs.get(sobj.id)
         self.assertIsNotNone(mobj)
         self.assertEqual(mobj.source_id, sobj.id)
         self.assertEqual(mobj.name, sobj.name)
         self.assertEqual(mobj.management_ip, sobj.host)
+        self.assertEqual(mobj.inactive, deleted)
         if sobj.site:
             site = sites.get(sobj.site)
             if site or not sobj.errors:
@@ -1256,6 +1258,12 @@ class TestModelSync(unittest.TestCase):
                 self.assertEqual(site.uuid, mobj.site_uuid)
         self.assertEqual(mobj.uuid, sobj._uuid)
 
+    async def checkSourceRouter(self, sobj, deleted=False):
+        return await self.checkSourceElement(sobj, ElementRole.ROUTER, deleted=deleted)
+
+    async def checkSourceOlt(self, sobj, deleted=False):
+        return await self.checkSourceElement(sobj, ElementRole.OLT, deleted=deleted)
+
     def test_router_create(self):
         """An Router is created in the model."""
         async def test():
@@ -1346,3 +1354,30 @@ class TestModelSync(unittest.TestCase):
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], routers=routers)
             await self.checkSourceRouter(router)
         self._await(test())
+
+    def test_olt(self):
+        """OLTs are handled properly in the model, the same way routers are."""
+        async def test():
+            # create an OLT
+            olt = Olt('olt01', host='192.0.2.1', name='OLT 1', site='Site 1')
+            olts = {'olt01': olt}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], olts=olts)
+            await self.checkSourceOlt(olt)
+
+            # add a router so we can test any interactions between them
+            router = Router('router01', host='192.0.2.254', name='Router 1', site='Site 1')
+            routers = {'router01': router}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], routers=routers)
+            await self.checkSourceOlt(olt)
+            await self.checkSourceRouter(router)
+
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], olts=olts, routers=routers)
+            await self.checkSourceOlt(olt)
+            await self.checkSourceRouter(router)
+
+            # Delete the router and update the OLT
+            olt.host = '192.0.2.2'
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], olts=olts, routers={})
+            await self.checkSourceOlt(olt)
+            await self.checkSourceRouter(router, deleted=True)
+        self._await(test())
